%{!?tcl_version: %global tcl_version %(echo 'puts $tcl_version' | tclsh)}

Name:           scid
Version:        4.6.4
Release:        1%{?dist}
Summary:        A chess database application
Group:          Amusements/Games
License:        GPLv2+ and distributable only in Scid
# src/egtb/* are distributable only in Scid
URL:            http://scid.sourceforge.net/
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.zip
Source1:        %{name}.desktop
# adjust search paths for spelling file and sounds in source code
Patch1:         scid-paths.patch
# fix CFLAGS
Patch2:         scid-makefile-phalanx.patch
Patch3:         scid-makefile-togaII.patch
# fix warnings during compilation of the egtb code
Patch4:         scid-egtb.patch
# adjust search paths for scid.css, scid.js and bitmaps
Patch5:         scid-HTML-export.patch
BuildRequires:  tk-devel desktop-file-utils
Requires:       tcl tk

%description
Scid can perform many different searches, such as for particular players, a
certain opening position, material searches, and pattern searches such as
isolated pawns. It is very fast, because it uses its own efficient format, but
it can convert games to and from PGN, the standard format for chess game files.

Scid can use a chess engine such as Crafty to analyze games and also has a
"tree" mode where it automatically shows all moves played from the current
position, their opening codes, success rates, etc.

%package sounds
Summary:        Sounds for move announcement
Group:          Amusements/Games
License:        GPLv2+
BuildArch:      noarch
Requires:       %{name}%{?_isa} = %{version}-%{release} tcl-snack

%description sounds
This package contains sounds for move announcement.

%package books
Summary:        Opening books
Group:          Amusements/Games
License:        GPLv2+ and freely redistributable
# books/{Performance.bin,varied.bin} are freely redistributable
# books/{Elo2400.bin,gm2600.bin} are GPL
BuildArch:      noarch
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description books
This package contains opening books for scid.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

rm -rf src/zlib

for file in {tcl/contrib/ezsmtp/{license.txt,ChangeLog,test_examples.txt,README.txt},engines/togaII1.2.1a/{copying.txt,readme.txt}}; do
        touch -r $file timestamp
        sed -i 's/\r$//' $file
        touch -r timestamp $file
        rm -f timestamp
done

for file in engines/togaII1.2.1a/readme.txt; do
        mv $file timestamp
        iconv -f ISO-8859-1 -t UTF-8 -o $file timestamp
        touch -r timestamp $file
        rm -f timestamp
done

%build
./configure \
        OPTIMIZE="%{optflags}" \
        BINDIR=%{_bindir} \
        SHAREDIR=%{_datadir}/%{name} \
        TCL_LIBRARY="-ltcl%{tcl_version}" \
        TK_LIBRARY="-ltk%{tcl_version} -ltcl%{tcl_version}"

make %{?_smp_mflags}

%install
mkdir -p %{buildroot}/%{_docdir}/%{name}/ezsmtp
mkdir -p %{buildroot}/%{_licensedir}/%{name}/ezsmtp
mv tcl/contrib/ezsmtp/{ChangeLog,ezsmtp.html,koi8-r-body.txt,README.txt,test_examples.txt} %{buildroot}/%{_docdir}/%{name}/ezsmtp
mv tcl/contrib/ezsmtp/license.txt %{buildroot}/%{_licensedir}/%{name}/ezsmtp

make DESTDIR=%{buildroot} install

desktop-file-install \
        --dir %{buildroot}/%{_datadir}/applications   \
        %{SOURCE1}

install -m 755 -d %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/
install -m 644 -p svg/scid_app.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/

install -m 755 -d %{buildroot}/%{_datadir}/%{name}/sounds/
install -m 644 -p sounds/*.wav %{buildroot}/%{_datadir}/%{name}/sounds/
install -m 755 -d %{buildroot}/%{_datadir}/scid/photos/

install -m 755 -d %{buildroot}/%{_datadir}/%{name}/bitmaps/
install -m 755 -d %{buildroot}/%{_datadir}/%{name}/bitmaps2/
install -m 644 -p bitmaps/*.gif %{buildroot}/%{_datadir}/%{name}/bitmaps/
install -m 644 -p bitmaps2/*.gif %{buildroot}/%{_datadir}/%{name}/bitmaps2/

# archiving files ifor docdir and licensedir
mv ChangeLog TODO %{buildroot}/%{_docdir}/%{name}
mv COPYING %{buildroot}/%{_licensedir}/%{name}
mkdir %{buildroot}/%{_docdir}/%{name}/{togaII,phalanx}
mkdir %{buildroot}/%{_licensedir}/%{name}/{togaII,phalanx}
mv engines/togaII1.2.1a/readme.txt %{buildroot}/%{_docdir}/%{name}/togaII
mv engines/togaII1.2.1a/copying.txt %{buildroot}/%{_licensedir}/%{name}/togaII
mv engines/phalanx-scid/{HISTORY,README} %{buildroot}/%{_docdir}/%{name}/phalanx
mv engines/phalanx-scid/COPYING %{buildroot}/%{_licensedir}/%{name}/phalanx

rm %{buildroot}/%{_datadir}/%{name}/tcl/lang/rename.sh
mkdir -p %{buildroot}/%{_licensedir}/%{name}/tcl/utils
mv %{buildroot}/%{_datadir}/%{name}/tcl/utils/tklib_license.terms %{buildroot}/%{_licensedir}/%{name}/tcl/utils 

# move all license files to the right place
mkdir -p %{buildroot}/%{_licensedir}/%{name}/img/buttons
mv %{buildroot}/%{_datadir}/%{name}/img/buttons/copyright %{buildroot}/%{_licensedir}/%{name}/img/buttons
mkdir -p %{buildroot}/%{_licensedir}/%{name}/img/flags
mv %{buildroot}/%{_datadir}/%{name}/img/flags/copyright %{buildroot}/%{_licensedir}/%{name}/img/flags
mkdir -p %{buildroot}/%{_licensedir}/%{name}/img/pieces/Alpha
mv %{buildroot}/%{_datadir}/%{name}/img/pieces/Alpha/copyright %{buildroot}/%{_licensedir}/%{name}/img/pieces/Alpha
mkdir -p %{buildroot}/%{_licensedir}/%{name}/img/pieces/Bauhaus
mv %{buildroot}/%{_datadir}/%{name}/img/pieces/Bauhaus/copyright %{buildroot}/%{_licensedir}/%{name}/img/pieces/Bauhaus
mkdir -p %{buildroot}/%{_licensedir}/%{name}/img/pieces/Merida
mv %{buildroot}/%{_datadir}/%{name}/img/pieces/Merida/copyright %{buildroot}/%{_licensedir}/%{name}/img/pieces/Merida
mkdir -p %{buildroot}/%{_licensedir}/%{name}/img/pieces/Leipzig
mv %{buildroot}/%{_datadir}/%{name}/img/pieces/Leipzig/copyright %{buildroot}/%{_licensedir}/%{name}/img/pieces/Leipzig

#fix book worldwrite
chmod 644 %{buildroot}/%{_datadir}/%{name}/books/*

#remove backup files 
rm %{buildroot}/%{_datadir}/%{name}/tcl/options.tcl.orig
rm %{buildroot}/%{_datadir}/%{name}/tcl/misc/misc.tcl.orig

%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
update-desktop-database &> /dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi
update-desktop-database &> /dev/null || :

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%files
%docdir %{_docdir}/%{name}/
%{_docdir}/%{name}/
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/scid.eco
%{_datadir}/%{name}/html
%{_datadir}/%{name}/bitmaps
%{_datadir}/%{name}/bitmaps2
%{_datadir}/%{name}/engines
%{_datadir}/%{name}/photos
%{_datadir}/%{name}/img
%{_datadir}/%{name}/tcl
%{_bindir}/*
%{_datadir}/applications/*
%{_datadir}/icons/hicolor/scalable/apps/*
%license %{_licensedir}/%{name}/

%files sounds
%{_datadir}/%{name}/sounds

%files books
%{_datadir}/%{name}/books

%changelog
* Sun Aug 14 2016 Sérgio Basto <sergio@serjux.com> - 4.6.4-1
- Update scid to 4.6.4
- Drop patch0, is upstreamed .

* Thu Oct 29 2015 Sérgio Basto <sergio@serjux.com> - 4.6.2-1
- Update to scid-4.6.2
- Spec cleanup
- move licence files and added %%docdir

* Mon May 04 2015 Mikhail Kalenkov <mikhail.kalenkov@gmail.com> - 4.6.0-1
- 4.6.0 update

* Wed Dec 24 2014 Mikhail Kalenkov <mikhail.kalenkov@gmail.com> - 4.5.2-5
- drop tkimg dependence

* Thu Dec 11 2014 Mikhail Kalenkov <mikhail.kalenkov@gmail.com> - 4.5.2-4
- rebuild for Fedora 21

* Wed Jan 15 2014 Mikhail Kalenkov <mikhail.kalenkov@gmail.com> - 4.5.2-3
- add tk to Requires

* Thu Nov 21 2013 Mikhail Kalenkov <mikhail.kalenkov@gmail.com> - 4.5.2-2
- fix build (pthread runtime error)

* Fri Nov 15 2013 Mikhail Kalenkov <mikhail.kalenkov@gmail.com> - 4.5.2-1
- update to 4.5.2

* Thu Apr 04 2013 Mikhail Kalenkov <mikhail.kalenkov@gmail.com> - 4.4-1
- update to scid-4.4

* Fri Jun 15 2012 Mikhail Kalenkov <mikhail.kalenkov@gmail.com> - 4.3-4
- rebuild for Fedora 17

* Wed Jan 11 2012 Mikhail Kalenkov <mikhail.kalenkov@gmail.com> - 4.3-3
- rebuild for Fedora 16

* Wed Feb 16 2011 Mikhail Kalenkov <mikhail.kalenkov@gmail.com> - 4.3-2
-

* Sun Feb 13 2011 Mikhail Kalenkov <mikhail.kalenkov@gmail.com> - 4.3-1
- update to 4.3

* Mon Nov 15 2010 Mikhail Kalenkov <mikhail.kalenkov@gmail.com> - 4.2.2-5
- make subpackages noarch

* Wed Nov 03 2010 Mikhail Kalenkov <mikhail.kalenkov@gmail.com> - 4.2.2-4
- fix search paths for scid.css, scid.js and bitmaps

* Sat May 29 2010 Mikhail Kalenkov <kalenkov@lpi.ru> - 4.2.2-3
- rebuild for Fedora 13

* Wed Jan 20 2010 Mikhail Kalenkov <kalenkov@lpi.ru> - 4.2.2-2
- update to 4.2.2

* Tue Jan 19 2010 Mikhail Kalenkov <kalenkov@lpi.ru> - 4.2-1
- update to 4.2

* Sat Jan 02 2010 Mikhail Kalenkov <kalenkov@lpi.ru> - 4.1-1
- update to 4.1

* Fri Nov 20 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 4.0-2
- rebuild for Fedora 12

* Sun Sep 06 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 4.0-1
- update to 4.0

* Sat Jul 25 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 4.0-0.2.beta1
- update to 4.0.beta1

* Fri Jun 19 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.3-9
- new icon

* Thu Jun 18 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.3-8
- fix license tags

* Thu Jun 18 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.3-7
- fix license tags

* Wed Jun 17 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.3-6
- fix compiler warnings in egtb code

* Wed Jun 17 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.3-5
- fix compiler warnings in egtb code

* Mon Jun 15 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.3-4
spec changes

* Tue Jun 09 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.3-3
add bitmaps to rpm, other minor fixes

* Mon Jun 08 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.3-2
fix timestamp

* Sat Apr 18 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.3-1
update to 3.7.3

* Mon Mar 02 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.1-2
update to 3.7.1

* Sat Feb 28 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.0-1
update to 3.7

* Sat Jan 31 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.0-0.5.beta4
minor changes in patches

* Wed Jan 28 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.0-0.4.beta4
update to 3.7beta4

* Sun Jan 11 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.0-0.3.beta3
package books/readme.txt as doc

* Sat Jan 10 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.7.0-0.2.beta3
adjust spec according Fedora Guidelines

* Fri Jan 09 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.6.26-12.3.7beta3
spec cleanup

* Wed Jan 07 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.6.26-11.3.7beta3
add patch (remove warnings)

* Sun Jan 04 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.6.26-9.3.7beta3
update to 3.7beta3

* Sat Jan 03 2009 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.6.26-8.3.7beta2
update to 3.7beta2

* Tue Dec 30 2008 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.6.26-6.cvs20081230
put opening books  into subpackage

* Tue Dec 30 2008 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.6.26-5.cvs20081230
put sound files into subpackage

* Tue Dec 30 2008 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.6.26-4.cvs20081230
split package

* Tue Dec 30 2008 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.6.26-3.cvs20081230
adopted spec file to build scid from cvs

* Mon Oct 13 2008 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.6.26-2
update to 3.6.26

* Tue Sep 02 2008 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.6.25-2
update to 3.6.25

* Sun Jul 06 2008 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.6.24-12
cleanup spec file

* Sat Jul 05 2008 Mikhail Kalenkov <kalenkov@lpi.ru> - 3.6.24-10
correct permissions

* Wed Jul 2 2008 - kalenkov@lpi.ru
- add dist tag
* Tue Jul 1 2008 - kalenkov@lpi.ru
- updated for 3.6.24
  * adopted SUSE spec file for the Fedora distribution
* Thu Feb 7 2008 - detlef.steuer@gmx.de
- updated for 3.6.22
* Mon Jan 14 2008 - detlef.steuer@gmx.de
- updated for 3.6.21
* Sat Nov 24 2007 - detlef.steuer@gmx.de
- first try with pgeorges scid
* Sat Oct 28 2006 - meissner@suse.de
- use RPM_OPT_FLAGS
* Wed Jan 25 2006 - mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Mar 03 2004 - mcihar@suse.cz
- update to 3.6.1
* Mon Feb 23 2004 - mcihar@suse.cz
- update to 3.5
* Sat Jan 10 2004 - adrian@suse.de
- build as user
* Mon Sep 22 2003 - ro@suse.de
- do not provuide phalanx
* Mon Jul 28 2003 - ro@suse.de
- added tk-devel to neededforbuild
* Tue May 27 2003 - mcihar@suse.cz
- move binaries to /usr/bin
* Thu Feb 06 2003 - mcihar@suse.cz
- updated to 3.4
  * Scid now has its own built-in analysis engine called Scidlet;
  you can still use other WinBoard-compatible engines for
  analysis in Scid, of course.
  * New Player Finder window.
  * More improvements to the Tablebase window.
  * Moves on the main window chessboard are now animated.
  * Lots of small user interface improvements.
  * Added support for entering null (empty) moves in games.
* Mon Aug 19 2002 - ro@suse.de
- add "-DUSE_NON_CONST" to cflags for new tcl
* Fri Jul 12 2002 - max@suse.de
- Patching Makefile.conf and using configure instead of
  patching Makefile, so that the Tcl/Tk version can be
  detected at build time.
* Thu Jun 13 2002 - mcihar@suse.cz
- updated to 3.3:
  * New "Piece Tracker" tool, new "Filter Graph" window
  * Maintenance window: new "Strip PGN tags" operation that finds
  extra PGN tags and allows the user to remove all instances of
  a particular unwanted tag.
  * Added "Load Random Game" menu command in the Game menu.
  * Extended search capabilities
  * Improved reading of annotations in PGN.
  * Removed limitation of game to 128 moves.
  * Improved the look of piece images in the chessboard.
* Wed Apr 24 2002 - pmladek@suse.cz
- used macro %%{_lib} to fix for lib64
* Tue Jan 29 2002 - pmladek@suse.cz
- updated to version 3.1
* Wed Dec 05 2001 - pmladek@suse.cz
- updated on version 3.0:
  * new database format
  * new "Bookmarks" feature
  * new "Tip of the day" window
  * most window locations and sizes are now saved in the options file
  when "Save Options" is selected.
  * tree window: New "Best games" window
  * 12 new user-settable "flags" for marking games with various chess
  characteristics.
- added tk to Requires
- fixed to load spelling.ssp
* Mon Jun 25 2001 - pblaha@suse.cz
- update on 2.5
* Wed May 30 2001 - pblaha@suse.cz
- update on 2.4
- rewrite URL
* Wed May 09 2001 - mfabian@suse.de
- bzip2 sources
* Tue Jan 16 2001 - pblaha@suse.cz
- create this package
